@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2.1
-id: persistent-sqlite-2.2.1-2e94993b109455a4a92def0668188dee
-key: persi_CR8cEK9Vka7INGJoLQ2HKU
+id: persistent-sqlite-2.2.1-69de5e2e0081e61b66553a26dd3337b5
+key: persi_BiM5usmC3JrBt21i2jK864
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,7 +20,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
-hs-libraries: HSpersistent-sqlite-2.2.1-CR8cEK9Vka7INGJoLQ2HKU
+hs-libraries: HSpersistent-sqlite-2.2.1-BiM5usmC3JrBt21i2jK864
 extra-libraries:
     pthread
 depends:
@@ -30,9 +30,9 @@ depends:
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-77245c726e2e1fb18d9b7ba72ab04e41
+    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
+    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
